Learn R Programming

NobBS (version 1.0.0)

denguedat: denguedat: Dengue fever reporting data from Puerto Rico

Description

Surveillance data from CDC Division of Vector-Borne Diseases. 1990-2010 case reporting data included. The first column, onset_week, indicates the week of symptom onset. The second column, report_week, indicates the week of case report. The third column, gender, indicates the gender of the infected individual (randomly assigned with 0.5:0.5 probability of "Male"/"Female"). This column may be used to produce stratified nowcasts using the function NobBS.strat.

Usage

data(denguedat)

Arguments

Format

A data frame.

Examples

Run this code
data(denguedat)
nowcast <- NobBS(denguedat, as.Date("1990-04-09"),units="1 week",onset_date="onset_week",
report_date="report_week")
nowcast$estimates

Run the code above in your browser using DataLab